# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nautobot_ssot_ipfabric',
 'nautobot_ssot_ipfabric.diffsync',
 'nautobot_ssot_ipfabric.migrations',
 'nautobot_ssot_ipfabric.tests',
 'nautobot_ssot_ipfabric.tests.fixtures',
 'nautobot_ssot_ipfabric.utilities']

package_data = \
{'': ['*'],
 'nautobot_ssot_ipfabric': ['static/nautobot_ssot_ipfabric/*',
                            'templates/nautobot_ssot_ipfabric/inc/*']}

install_requires = \
['Markdown==3.3.4',
 'nautobot-chatops-ipfabric>=1.0.0,<2.0.0',
 'nautobot-chatops>=1.5.0,<2.0.0',
 'nautobot-ssot>=1.0.1,<2.0.0',
 'netutils>=0.2.3,<0.3.0']

extras_require = \
{'nautobot': ['nautobot']}

entry_points = \
{'nautobot.workers': ['ipfabric = nautobot_ssot_ipfabric.workers:ipfabric']}

setup_kwargs = {
    'name': 'nautobot-ssot-ipfabric',
    'version': '0.9.0.dev0',
    'description': 'Nautobot SSoT IPFabric',
    'long_description': '# Nautobot SSoT IPFabric\n\nAn [SSoT](https://blog.networktocode.com/post/nautobot-ssot-plugin/) plugin providing a simple way to synchronize data between [IPFabric](https://ipfabric.io/) and [Nautobot](https://github.com/nautobot/nautobot). Ensure data stays consistent between the two platforms by leveraging [DiffSync](https://github.com/networktocode/diffsync) capabilities and allowing users to take full advantage of both platforms with up-to-date, synchronized data.\n\n## Build Status\n\n| Branch      | Status                                                                                                                                                                                                            |\n| ----------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |\n| **main**    | ![Build Status](https://github.com/nautobot/nautobot-plugin-ssot-ipfabric/actions/workflows/nautobot-ssot-ipfabric-ci.yml/badge.svg?branch=main)    |\n| **develop** | ![Build Status](https://github.com/nautobot/nautobot-plugin-ssot-ipfabric/actions/workflows/nautobot-ssot-ipfabric-ci.yml/badge.svg?branch=develop)|\n\n## Documentation\n\nDocumentation is hosted with Github Pages at [Nautobot SSoT IP Fabric Documentation](https://nautobot.github.io/nautobot-plugin-ssot-ipfabric/)\n\n## Installation\n\nTo install the plugin from Pypi\n\n```shell\npip install nautobot-ssot-ipfabric\n```\n\nTo install the plugin manually from repository code\n\n```shell\ngit clone git@github.com:nautobot/nautobot-plugin-ssot-ipfabric.git\n```\n\n```bash\ncd nautobot-plugin-ssot-ipfabric\n```\n\n```shell\npip install .\n```\n\nFor additional detailed instructions on how to install Nautobot Plugins, checkout the [official documentation](https://nautobot.readthedocs.io/en/latest/plugins/#installing-plugins)\n\n### Environment Variables\n\nThis plugin relies on user provided environment variables to interact with IP Fabric.\n\n- `ipfabric_api_token` - API Token for IP Fabric\n- `ipfabric_host` - IP Fabric URL\n- `nautobot_host` - Nautobot URL (This is used to generate url links for chatops)\n\nExample `PLUGINS_CONFIG` to be updated in `nautobot_config.py` after successful installation. The chatops configuration is optional, but if you\'d like to have the\nability to call the sync job through chatops, you will be required to configure it.\n\n```python\nPLUGINS_CONFIG = {\n    "nautobot_chatops": {\n        "enable_slack": True,\n        "slack_api_token": os.environ.get("SLACK_API_TOKEN"),\n        "slack_signing_secret": os.environ.get("SLACK_SIGNING_SECRET"),\n        "session_cache_timeout": 3600,\n    },\n    "nautobot_ssot_ipfabric": {\n        "ipfabric_api_token": os.environ.get("IPFABRIC_API_TOKEN"),\n        "ipfabric_host": os.environ.get("IPFABRIC_HOST"),\n        "nautobot_host": os.environ.get("NAUTOBOT_HOST"),\n    },\n    "nautobot_ssot": {"hide_example_jobs": True},\n    "nautobot_chatops_ipfabric": {\n        "IPFABRIC_API_TOKEN": os.environ.get("IPFABRIC_API_TOKEN"),\n        "IPFABRIC_HOST": os.environ.get("IPFABRIC_HOST"),\n    },\n}\n```\n\n## ChatOps\n\nAs part of the SSoT synchronization capabilities with IP Fabric, this plugin extends the [Nautobot Plugin Chatops IPFabric](https://github.com/nautobot/nautobot-plugin-chatops-ipfabric) by providing users with the ability to begin the sync job from a chatops command (Slack).\n\n![ssot-chatops-sync](docs/images/chatops-ssot-ipfabric.png)\n\n## Contributing\n\nPull requests are welcomed and automatically built and tested against multiple versions of Python and multiple version of Nautobot through Github Actions.\n\nThe project is packaged with a light development environment based on `docker-compose` to help with the local development of the project and to run the tests within Github Actions.\n\nThe project is following Network to Code software development guideline and is leveraging:\n\n- Black, Pylint, Bandit and pydocstyle for Python linting and formatting.\n- Django unit test to ensure the plugin is working properly.\n\n### Development Environment\n\nThe development environment can be used in 2 ways. First, with a local poetry environment if you wish to develop outside of Docker with the caveat of using external services provided by Docker for PostgresQL and Redis. Second, all services are spun up using Docker and a local mount so you can develop locally, but Nautobot is spun up within the Docker container.\n\nBelow is a quick start guide if you\'re already familiar with the development environment provided, but if you\'re not familiar, please read the [Getting Started Guide](GETTING_STARTED.md).\n\n#### Invoke\n\nThe [PyInvoke](http://www.pyinvoke.org/) library is used to provide some helper commands based on the environment.  There are a few configuration parameters which can be passed to PyInvoke to override the default configuration:\n\n- `nautobot_ver`: the version of Nautobot to use as a base for any built docker containers (default: 1.1.4)\n- `project_name`: the default docker compose project name (default: nautobot_ssot_ipfabric)\n- `python_ver`: the version of Python to use as a base for any built docker containers (default: 3.6)\n- `local`: a boolean flag indicating if invoke tasks should be run on the host or inside the docker containers (default: False, commands will be run in docker containers)\n- `compose_dir`: the full path to a directory containing the project compose files\n- `compose_files`: a list of compose files applied in order (see [Multiple Compose files](https://docs.docker.com/compose/extends/#multiple-compose-files) for more information)\n\nUsing **PyInvoke** these configuration options can be overridden using [several methods](http://docs.pyinvoke.org/en/stable/concepts/configuration.html).  Perhaps the simplest is simply setting an environment variable `INVOKE_NAUTOBOT_SSOT_IPFABRIC_VARIABLE_NAME` where `VARIABLE_NAME` is the variable you are trying to override.  The only exception is `compose_files`, because it is a list it must be overridden in a yaml file.  There is an example `invoke.yml` (`invoke.example.yml`) in this directory which can be used as a starting point.\n\n#### Local Poetry Development Environment\n\n1. Copy `development/creds.example.env` to `development/creds.env` (This file will be ignored by Git and Docker)\n2. Uncomment the `POSTGRES_HOST`, `REDIS_HOST`, and `NAUTOBOT_ROOT` variables in `development/creds.env`\n3. Create an `invoke.yml` file with the following contents at the root of the repo (you can also `cp invoke.example.yml invoke.yml` and edit as necessary):\n\n```yaml\n---\nnautobot_ssot_ipfabric:\n  local: true\n  compose_files:\n    - "docker-compose.requirements.yml"\n```\n\n4. Run the following commands:\n\n```shell\npoetry shell\npoetry install --extras nautobot\nexport $(cat development/dev.env | xargs)\nexport $(cat development/creds.env | xargs)\ninvoke start && sleep 5\nnautobot-server migrate\n```\n\n> If you want to develop on the latest develop branch of Nautobot, run the following command: `poetry add --optional git+https://github.com/nautobot/nautobot@develop`. After the `@` symbol must match either a branch or a tag.\n\n4. You can now run nautobot-server commands as you would from the [Nautobot documentation](https://nautobot.readthedocs.io/en/latest/) for example to start the development server:\n\n```shell\nnautobot-server runserver 0.0.0.0:8080 --insecure\n```\n\nNautobot server can now be accessed at [http://localhost:8080](http://localhost:8080).\n\nIt is typically recommended to launch the Nautobot **runserver** command in a separate shell so you can keep developing and manage the webserver separately.\n\n#### Docker Development Environment\n\nThis project is managed by [Python Poetry](https://python-poetry.org/) and has a few requirements to setup your development environment:\n\n1. Install Poetry, see the [Poetry Documentation](https://python-poetry.org/docs/#installation) for your operating system.\n2. Install Docker, see the [Docker documentation](https://docs.docker.com/get-docker/) for your operating system.\n\nOnce you have Poetry and Docker installed you can run the following commands to install all other development dependencies in an isolated python virtual environment:\n\n```shell\npoetry shell\npoetry install\ninvoke start\n```\n\nNautobot server can now be accessed at [http://localhost:8080](http://localhost:8080).\n\nTo either stop or destroy the development environment use the following options.\n\n- **invoke stop** - Stop the containers, but keep all underlying systems intact\n- **invoke destroy** - Stop and remove all containers, volumes, etc. (This results in data loss due to the volume being deleted)\n\n### CLI Helper Commands\n\nThe project is coming with a CLI helper based on [invoke](http://www.pyinvoke.org/) to help setup the development environment. The commands are listed below in 3 categories `dev environment`, `utility` and `testing`.\n\nEach command can be executed with `invoke <command>`. Environment variables `INVOKE_NAUTOBOT_SSOT_IPFABRIC_PYTHON_VER` and `INVOKE_NAUTOBOT_SSOT_IPFABRIC_NAUTOBOT_VER` may be specified to override the default versions. Each command also has its own help `invoke <command> --help`\n\n#### Docker dev environment\n\n```no-highlight\n  build            Build all docker images.\n  debug            Start Nautobot and its dependencies in debug mode.\n  destroy          Destroy all containers and volumes.\n  restart          Restart Nautobot and its dependencies.\n  start            Start Nautobot and its dependencies in detached mode.\n  stop             Stop Nautobot and its dependencies.\n```\n\n#### Utility\n\n```no-highlight\n  cli              Launch a bash shell inside the running Nautobot container.\n  create-user      Create a new user in django (default: admin), will prompt for password.\n  makemigrations   Run Make Migration in Django.\n  nbshell          Launch a nbshell session.\n  shell-plus       Launch a shell_plus session, which uses iPython and automatically imports all models.\n```\n\n#### Testing\n\n```no-highlight\n  bandit           Run bandit to validate basic static code security analysis.\n  black            Run black to check that Python files adhere to its style standards.\n  flake8           This will run flake8 for the specified name and Python version.\n  pydocstyle       Run pydocstyle to validate docstring formatting adheres to NTC defined standards.\n  pylint           Run pylint code analysis.\n  tests            Run all tests for this plugin.\n  unittest         Run Django unit tests for the plugin.\n```\n\n### Project Documentation\n\nDocumentation is auto-generated with Sphinx, myst-paerser and sphinx-autoapi. The latest code in the `main` branch is providing the documentation with Github Pages. To build documentation locally as you are developing, perform the following commands.\n\n```shell\nsphinx-build -vvv -b html ./docs docs/public\ncd docs/public\npython -m http.server\n```\n\nNow you can access the documentation locally at `http://localhost:8000/` or the IP of the server hosting the development environment.\n\n## Questions\n\nFor any questions or comments, please check the [FAQ](FAQ.md) first and feel free to swing by the [Network to Code slack channel](https://networktocode.slack.com/) (channel #networktocode).\nSign up [here](http://slack.networktocode.com/)\n\n## Screenshots\n\nMain SSoT IP Fabric Dashboard\n![Dashboard](docs/images/dashboard.png)\n\nSync Details\n![Dashboard](docs/images/sync_details.png)\n',
    'author': 'Network to Code, LLC',
    'author_email': 'info@networktocode.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/networktocode-llc/nautobot-plugin-ssot-ipfabric',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.6.2,<4.0',
}


setup(**setup_kwargs)
